==> iTop-3.0.3-10998.zip: web/datamodels/2.x/itop-attachments/dictionaries/fr.dict.itop-attachments.php <==
<?php
/**
 * Copyright (C) 2013-2021 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */
Dict::Add('FR FR', 'French', 'Français', array(
	'Attachments:TabTitle_Count' => 'Pièces jointes (%1$d)',
	'Attachments:EmptyTabTitle' => 'Pièces jointes',
	'Attachments:FieldsetTitle' => 'Pièces jointes',
	'Attachments:DeleteBtn' => 'Supprimer',
	'Attachments:History_File_Added' => 'Ajout de la pièce jointe: %1$s.',
	'Attachments:History_File_Removed' => 'Suppression de la pièce jointe: %1$s.',
	'Attachments:AddAttachment' => 'Ajouter une pièce jointe: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Le téléchargement de fichiers est interdit sur ce système.',
	'Attachment:Max_Go' => '(Taille de fichier max.: %1$s Gb)',
	'Attachment:Max_Mo' => '(Taille de fichier max.: %1$s Mb)',
	'Attachment:Max_Ko' => '(Taille de fichier max.: %1$s Kb)',
	'Attachments:NoAttachment' => 'Aucune pièce jointe.',
	'Attachments:PreviewNotAvailable' => 'Pas d\'aperçu pour ce type de pièce jointe.',
	'Attachments:Error:FileTooLarge' => 'Le fichier est trop gros pour être chargé. %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Le fichier téléchargé est vide et ne peut pas être attaché.
Soit vous avez attaché un fichier vide,
Soit demandez à votre administrateur système s\'il reste de la place disque disponible sur le serveur',
	'Attachments:Render:Icons' => 'Affichage en icônes',
	'Attachments:Render:Table' => 'Affichage en liste',
	'UI:Attachments:DropYourFileHint' => 'Déposez vos fichiers dans cet espace',
));

//
// Class: Attachment
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:Attachment' => 'Attachement',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:expire' => 'Expire',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Id Temporaire',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Classe d\'Item',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Item',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organisation de l\'Item',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Contenu',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('FR FR', 'French', 'Français', array(
	'Attachments:File:Thumbnail' => 'Icône',
	'Attachments:File:Name' => 'Nom du fichier',
	'Attachments:File:Date' => 'Date de chargement',
	'Attachments:File:Uploader' => 'Chargé par',
	'Attachments:File:Size' => 'Taille',
	'Attachments:File:MimeType' => 'Type',
));
//
// Class: Attachment
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:Attachment/Attribute:creation_date' => 'Date de création',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'Utilisateur',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Contact',
	'Class:Attachment/Attribute:contact_id+' => '',
));

==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-attachments/dictionaries/fr.dict.itop-attachments.php <==
<?php
/**
 * Copyright (C) 2013-2023 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */
Dict::Add('FR FR', 'French', 'Français', array(
	'Attachments:TabTitle_Count' => 'Pièces jointes (%1$d)',
	'Attachments:EmptyTabTitle' => 'Pièces jointes',
	'Attachments:FieldsetTitle' => 'Pièces jointes',
	'Attachments:DeleteBtn' => 'Supprimer',
	'Attachments:History_File_Added' => 'Ajout de la pièce jointe: %1$s.',
	'Attachments:History_File_Removed' => 'Suppression de la pièce jointe: %1$s.',
	'Attachments:AddAttachment' => 'Ajouter une pièce jointe: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Le téléchargement de fichiers est interdit sur ce système.',
	'Attachment:Max_Go' => '(Taille de fichier max.: %1$s Gb)',
	'Attachment:Max_Mo' => '(Taille de fichier max.: %1$s Mb)',
	'Attachment:Max_Ko' => '(Taille de fichier max.: %1$s Kb)',
	'Attachments:NoAttachment' => 'Aucune pièce jointe.',
	'Attachments:PreviewNotAvailable' => 'Pas d\'aperçu pour ce type de pièce jointe.',
	'Attachments:Error:FileTooLarge' => 'Le fichier est trop gros pour être chargé. %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Le fichier téléchargé est vide et ne peut pas être attaché.
Soit vous avez attaché un fichier vide,
Soit demandez à votre administrateur système s\'il reste de la place disque disponible sur le serveur',
	'Attachments:Render:Icons' => 'Affichage en icônes',
	'Attachments:Render:Table' => 'Affichage en liste',
	'UI:Attachments:DropYourFileHint' => 'Déposez vos fichiers dans cet espace',
));

//
// Class: Attachment
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:Attachment' => 'Attachement',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:expire' => 'Expire',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Id Temporaire',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Classe d\'Item',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Item',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organisation de l\'Item',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Contenu',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('FR FR', 'French', 'Français', array(
	'Attachments:File:Thumbnail' => 'Icône',
	'Attachments:File:Name' => 'Nom du fichier',
	'Attachments:File:Date' => 'Date de chargement',
	'Attachments:File:Uploader' => 'Chargé par',
	'Attachments:File:Size' => 'Taille',
	'Attachments:File:MimeType' => 'Type',
	'Attachments:File:DownloadsCount' => 'Téléchargements',
));
//
// Class: Attachment
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:Attachment/Attribute:creation_date' => 'Date de création',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'Utilisateur',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Contact',
	'Class:Attachment/Attribute:contact_id+' => '',
));

//
// Class: TriggerOnAttachmentDownload
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:TriggerOnAttachmentDownload' => 'Déclencheur sur le téléchargement d\'une pièce jointe d\'un objet',
	'Class:TriggerOnAttachmentDownload+' => '',
));
